@@ -174,7 +174,7 @@ class Config:
             read_dict = files
             read_files = files.values()
         # If user didn't give a dict ensure they have run define_files()
-        else:
+        elif hasattr(self, "files"):
             read_dict = self.files
             read_files = files
         # User has passed a list that does not have any meaning
@@ -187,9 +187,11 @@ class Config:
             if not key in read_files:
                 continue
             if json_file:
-                with open(file, 'r') as data:
-                    jdata = json.load(data)
-                setattr(self, key, jdata)
+                try:
+                    with open(file, 'r') as data:
+                        jdata = json.load(data)
+                except json.decoder.JSONDecodeError:
+                    jdata = {}
                 temp_dict[key] = jdata
             else:
                 with open(file) as f:
